@@ -79,10 +79,10 @@ var PlacesOrganizer = {
     // Set up the search UI.
     PlacesSearchBox.init();
 
-//@line 86 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/places/content/places.js"
+//@line 86 "/icecat-3.5.7/browser/components/places/content/places.js"
 
     window.addEventListener("AppCommand", this, true);
-//@line 109 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/places/content/places.js"
+//@line 109 "/icecat-3.5.7/browser/components/places/content/places.js"
 
     // remove the "Properties" context-menu item, we've our own details pane
     document.getElementById("placesContext")
@@ -530,11 +530,7 @@ var PlacesOrganizer = {
     var backupsDir = dirSvc.get("Desk", Ci.nsILocalFile);
     fp.displayDirectory = backupsDir;
 
-    // Use YYYY-MM-DD (ISO 8601) as it doesn't contain illegal characters
-    // and makes the alphabetical order of multiple backup files more useful.
-    var date = (new Date).toLocaleFormat("%Y-%m-%d");
-    fp.defaultString = PlacesUIUtils.getFormattedString("bookmarksBackupFilenameJSON",
-                                                        [date]);
+    fp.defaultString = PlacesUtils.getBackupFilename();
 
     if (fp.show() != Ci.nsIFilePicker.returnCancel) {
       PlacesUtils.backupBookmarksToFile(fp.file);
@@ -543,9 +539,7 @@ var PlacesOrganizer = {
       var latestBackup = PlacesUtils.getMostRecentBackup();
       if (!latestBackup || latestBackup != fp.file) {
         latestBackup.remove(false);
-        var date = new Date().toLocaleFormat("%Y-%m-%d");
-        var name = PlacesUtils.getFormattedString("bookmarksArchiveFilename",
-                                                  [date]);
+        var name = PlacesUtils.getBackupFilename();
         fp.file.copyTo(this.bookmarksBackupDir, name);
       }
     }
@@ -787,9 +781,9 @@ var PlacesOrganizer = {
     // If the advanced query builder is showing, use that.
     var options = this.getCurrentOptions();
 
-//@line 816 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/places/content/places.js"
+//@line 810 "/icecat-3.5.7/browser/components/places/content/places.js"
     var queries = this.getCurrentQueries();
-//@line 818 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/places/content/places.js"
+//@line 812 "/icecat-3.5.7/browser/components/places/content/places.js"
 
     var placeSpec = PlacesUtils.history.queriesToQueryString(queries,
                                                              queries.length,
@@ -994,7 +988,7 @@ var PlacesSearchBox = {
     var searchModifiers = document.getElementById("searchModifiers");
     searchModifiers.hidden = false;
 
-//@line 1027 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/places/content/places.js"
+//@line 1021 "/icecat-3.5.7/browser/components/places/content/places.js"
   },
 
   hideSearchUI: function PSB_hideSearchUI() {
@@ -1011,7 +1005,7 @@ var PlacesQueryBuilder = {
   queries: [],
   queryOptions: null,
 
-//@line 1506 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/places/content/places.js"
+//@line 1500 "/icecat-3.5.7/browser/components/places/content/places.js"
 
   /**
    * Called when a scope button in the scope bar is clicked.
